---
sidebar: auto
---

# Glossary

You may stumble upon some unfamiliar concepts in the documentation. This section lists the common terms in the documentation for easy access, learning and development.
